@@ -3,7 +3,6 @@
 #                                                                                                       #
 # translate the parsed antlr4 rules to Marpa::R2 syntax.                                                #
 #                                                                                                       #
-# V 1.0                                                                                                 #
 # ----------------------------------------------------------------------------------------------------- #
 
 package MarpaX::G4::MarpaGen;
@@ -855,7 +854,7 @@ sub processRightSides
     my $groupisLexeme       = { status => 0 };
     my $keywordfragment     = { status => 0 };
 
-    # if ($rulename eq "WS")
+    # if ( $rulename eq "outer_join_sign")
     # {
     #     printf "found!\n";
     # }
@@ -1048,6 +1047,11 @@ sub processRightSides
 
         push @$currentlist, $mxelement;
         ++$alternativelength;
+
+        ##
+        #   a list of lexemes is not itself a lexeme (unless declared in the 'lexer' grammar).
+        ##
+        $groupisLexeme->{status} = -1 if $alternativelength > 1;
     }
 
     ##
@@ -1110,7 +1114,7 @@ sub walkrule
 {
     my ($self, $rulename, $rule, $context) = @_;
 
-    # if ( $rulename eq "ACCEPT")
+    # if ( $rulename eq "outer_join_sign")
     # {
     #     printf "found!\n";
     # }
@@ -1739,7 +1743,7 @@ sub writeMarpaRuleList
                     }
                     else
                     {
-                        mydie "unexpected embedded 'list'";
+                        mydie "writeMarpaRuleList : unexpected embedded 'list'";
                     }
                     last SWITCH;
                 };
@@ -1800,7 +1804,7 @@ sub writeMarpaRule
 
     $self->tagMarpaRule($rulename);
 
-    # if ( $rulename eq "SEPARATOR")
+    # if ( $rulename eq "IDENTIFIER")
     # {
     #     printf "found!\n";
     # }
