@@ -1,9 +1,8 @@
 # ----------------------------------------------------------------------------------------------------- #
 # MarpaX::G4                                                                                            #
 #                                                                                                       #
-# a grammar for parsing antlr4 grammars and translating them to Marpa grammars.                         #
+# a grammar for parsing antlr4 grammars and translating them to Marpa::R2 grammars.                     #
 #                                                                                                       #
-# V 1.0                                                                                                 #
 # ----------------------------------------------------------------------------------------------------- #
 
 package MarpaX::G4::Parser;
@@ -175,7 +174,7 @@ opt_return                          ::=
 opt_return                          ::= 'returns' (LBRACKET) namelist (RBRACKET)            action => do_return_clause
 namelist                            ::= name+
 
-optionspec                          ::= <Options Prefix> <Inline Action>                    action => do_options_spec
+optionspec                          ::= <Options Prefix> <Inline Action>                    action => do_option_spec
 <Options Prefix>                    ~   'options'
                                     |   'channels'
                                     |   'tokens'
@@ -315,6 +314,7 @@ sub flattenArray
 sub default_action
 {
     my ($self, @items ) = @_;
+    $self->do_trace("default_action", \@items);
     my $result = \@items;
     $result = $items[0] if scalar @items == 1;
     return $result;
@@ -326,10 +326,10 @@ sub do_grammar
     return \@rules;
 }
 
-sub do_options_spec
+sub do_option_spec
 {
     my ($self, @items) = @_;
-    $self->do_trace("do_options_spec", \@items);
+    $self->do_trace("do_option_spec", \@items);
     my $value = $items[1]->{action};
     $value = join("\n", @$value) if ref($value) eq "ARRAY";
     my $result = { comment => sprintf("%s : <%s>", $items[0], $value) };
@@ -645,11 +645,8 @@ sub do_rhs
 {
     my ($self, @items) = @_;
     $self->do_trace("do_rhs", \@items);
-
     my $result = $items[0];
-
     $result = \@items if scalar @items > 1;
-
     return $result;
 }
 
@@ -674,7 +671,6 @@ sub do_nonterminal
                 $self->abortWithError( "'rulecomponent' must be a scalar or a hash", $rulecomponent );
             }
         }
-
         $rulecomponent->{cardinality}  = $self->flattenArray($opt_card);
     }
 
@@ -691,7 +687,6 @@ sub do_nonterminal
                 $self->abortWithError( "'rulecomponent' must be a scalar or a hash", $rulecomponent );
             }
         }
-
         $rulecomponent->{associativity} = $self->flattenArray($opt_assoc);
     }
 
@@ -713,10 +708,9 @@ sub do_group
     $self->do_trace("do_group", \@items);
     my ( $opt_colon, $rhs, $grouplist, $opt_bar ) = @items;
 
-    $rhs = $rhs->[1] if ref $rhs eq "ARRAY" && scalar @$rhs == 1;
-
     my $resultlist = [];
 
+    $rhs = $rhs->[1]                          if ref $rhs eq "ARRAY" && scalar @$rhs == 1;
     push @$resultlist, $rhs;
 
     push @$resultlist, $grouplist             if ref $grouplist eq "HASH";
@@ -812,6 +806,7 @@ sub do_token
 sub do_assignalias
 {
     my ($self, @items ) = @_;
+    $self->do_trace("do_assignalias", \@items);
     # alias op can be '=' or '+='
     my $result = { token => $items[2], alias => { name => $items[0], op => $items[1] } };
     return $result;
